@@ -55,7 +55,7 @@ IndexedEdictFile::~IndexedEdictFile()
 bool IndexedEdictFile::buildIndex()
 {
   KProcess proc;
-  proc << QStandardPaths::findExecutable("kitengen") << m_dictFile.fileName() << m_indexFile.fileName();
+  proc << QStandardPaths::findExecutable(QStringLiteral("kitengen")) << m_dictFile.fileName() << m_indexFile.fileName();
   proc.start();
   proc.waitForStarted();
 
@@ -219,7 +219,7 @@ QVector<QString> IndexedEdictFile::findMatches( const QString &query ) const
     return results;
   }
 
-  qSort( possibleHits );
+  std::sort(possibleHits.begin(), possibleHits.end());
   uint32_t last = 0;
 
   foreach( uint32_t it, possibleHits )
